@@ -1,5 +1,8 @@
 import sys,os,time
-
+import inspect
+__file__=inspect.getfile(inspect.currentframe())
+sys.path.append(os.path.dirname(__file__))
+from src import *
 LugwitPath=r'Z:\plug_in\Lugwit_plug'
 LugwitPath_ip=r'\\172.21.1.79\z\plug_in\Lugwit_plug'
 plug_inPath=r'Z:\plug_in'
